@@ -1,5 +1,5 @@
 package BalanceOfPower::Commands;
-$BalanceOfPower::Commands::VERSION = '0.131000';
+$BalanceOfPower::Commands::VERSION = '0.140000';
 use v5.10;
 use Moo;
 use IO::Prompter;
@@ -172,6 +172,7 @@ With a nation selected you can use:
 <events>
 <status>
 <history>
+<plot %attribute%>
 [year/turn]
 You can also say one of those commands as: [nation name] [command]
 
@@ -181,10 +182,14 @@ say <years> for available range of years
 
 say <wars> for a list of wars, <crises> for all the ongoing crises
 
+say <war history> for a list of finished wars
+
 say <hotspots> gives you wars and crises with also your diplomatic relationship with countries involved
 
 say <supports> for military supports
 
+say <rebel supports> for rebel military supports
+
 say <distance NATION1-NATION2> for distance between nations
 
 say <turn> to elaborate events for a new turn
@@ -269,6 +274,11 @@ COMMANDS
         say $self->world->print_military_supports();  
         $result = { status => 1 };
     }
+    elsif($query eq "rebel supports")
+    {
+        say $self->world->print_rebel_military_supports();  
+        $result = { status => 1 };
+    }
     elsif($query =~ /^distance (.*)-(.*)$/)
     {
         my $n1 = $self->world->correct_nation_name($1);
@@ -390,7 +400,21 @@ COMMANDS
         {
             $self->nation($self->world->player_nation);
         }
-        print $self->world->print_nation_statistics($self->nation, $self->world->first_year, $self->world->current_year);
+        print $self->world->print_nation_statistics($self->nation, $self->world->first_year, prev_turn($self->world->current_year));
+        $result = { status => 1 };
+    }
+    elsif($query =~ /^((.*) )?plot (.*)$/)
+    {
+        my $input_nation = $self->world->correct_nation_name($2);
+        if($input_nation)
+        {
+            $self->nation($input_nation);
+        }
+        if(! $self->nation)
+        {
+            $self->nation($self->world->player_nation);
+        }
+        print $self->world->plot_nation_factor($self->nation, $3, $self->world->first_year, prev_turn($self->world->current_year));
         $result = { status => 1 };
     }
     else
@@ -463,6 +487,7 @@ sub interact
         if($result->{status} == 1)
         {
             say "Elaborating " . $self->world->current_year . "...\n";
+            $self->world->decisions();
             $self->world->post_decisions_elaborations();
             say evidence_text($self->world->print_formatted_turn_events($self->world->current_year), $self->world->player_nation);
             $self->world->pre_decisions_elaborations();
