@@ -1,5 +1,5 @@
 package BalanceOfPower::Commands::RecallMilitarySupport;
-$BalanceOfPower::Commands::RecallMilitarySupport::VERSION = '0.131000';
+$BalanceOfPower::Commands::RecallMilitarySupport::VERSION = '0.140000';
 use Moo;
 
 use BalanceOfPower::Constants ':all';
@@ -9,7 +9,7 @@ extends 'BalanceOfPower::Commands::TargetNation';
 sub get_available_targets
 {
     my $self = shift;
-    my @supported = $self->world->supporter($self->world->actor);
+    my @supported = $self->world->supporter($self->actor);
     my @out = ();
     for(@supported)
     {
@@ -24,11 +24,11 @@ sub IA
     my $actor = $self->get_nation();
     if($actor->army <= ARMY_TO_RECALL_SUPPORT)
     {
-        my @supports = $self->world->supporter($actor->name);
+        my @supports = $self->get_available_targets();
         if(@supports > 0)
         {
             @supports = $self->world->shuffle("Choosing support to recall", @supports);
-            return "RECALL MILITARY SUPPORT " . $supports[0]->destination($actor->name);
+            return "RECALL MILITARY SUPPORT " . $supports[0];
         }
     }
     return undef;
