@@ -1,5 +1,5 @@
 package BalanceOfPower::Executive;
-$BalanceOfPower::Executive::VERSION = '0.131000';
+$BalanceOfPower::Executive::VERSION = '0.140000';
 use strict;
 use v5.10;
 
@@ -14,6 +14,7 @@ use BalanceOfPower::Commands::InMilitaryRange;
 use BalanceOfPower::Commands::DeleteRoute;
 use BalanceOfPower::Commands::MilitarySupport;
 use BalanceOfPower::Commands::RebelMilitarySupport;
+use BalanceOfPower::Commands::RecallRebelMilitarySupport;
 use BalanceOfPower::Commands::RecallMilitarySupport;
 use BalanceOfPower::Commands::ComTreaty;
 use BalanceOfPower::Commands::NagTreaty;
@@ -24,6 +25,7 @@ use BalanceOfPower::Commands::EconomicAid;
 use BalanceOfPower::Commands::DeclareWar;
 use BalanceOfPower::Commands::AidInsurgents;
 use BalanceOfPower::Commands::DiplomaticPressure;
+use BalanceOfPower::Commands::MilitaryAid;
 
 has actor => (
     is => 'rw',
@@ -132,6 +134,18 @@ sub init
                                                              prestige_cost => DIPLOMATIC_PRESSURE_PRESTIGE_COST
                                                     );
     $self->commands->{"DIPLOMATIC PRESSURE ON"} = $command; 
+    $command =
+        BalanceOfPower::Commands::RecallRebelMilitarySupport->new( name => "RECALL REBEL MILITARY SUPPORT",
+                                                                   world => $world,
+                                                                 );
+    $self->commands->{"RECALL REBEL MILITARY SUPPORT"} = $command; 
+    $command =
+        BalanceOfPower::Commands::MilitaryAid->new( name => "MILITARY AID FOR",
+                                                    world => $world,
+                                                    export_cost => MILITARY_AID_COST,
+                                                  );
+    $self->commands->{"MILITARY AID FOR"} = $command;
+   
 }
 
 
