@@ -1,5 +1,5 @@
 package BalanceOfPower::Nation;
-$BalanceOfPower::Nation::VERSION = '0.131000';
+$BalanceOfPower::Nation::VERSION = '0.140000';
 use strict;
 use v5.10;
 
@@ -75,6 +75,11 @@ has army => (
     is => 'rw'
 );
 
+has frozen_disorder => (
+    default => 0,
+    is => 'rw'
+);
+
 sub production
 {
     my $self = shift;
@@ -196,6 +201,7 @@ sub calculate_disorder
     my $self = shift;
     my $world = shift;
     return if($self->internal_disorder_status eq 'Civil war');
+    return if($self->frozen_disorder);
 
     #Variables
     my $wd = $self->wealth / PRODUCTION_UNITS->[$self->size];
@@ -217,7 +223,7 @@ sub calculate_disorder
                    $world->random_around_zero($random_factor_max, 100, "Internal disorder random factor for " . $self->name);
     $disorder = int ($disorder * 100) / 100;
     $self->register_event("DISORDER CHANGE: " . $disorder);
-    $self->add_internal_disorder($disorder);
+    $self->add_internal_disorder($disorder, $world);
 }
 
 sub subtract_production
@@ -247,10 +253,15 @@ sub add_wealth
 sub lower_disorder
 {
     my $self = shift;
+    my $world = shift;
+    if($world->at_civil_war($self->name))
+    {
+        return; 
+    }
     if($self->production_for_domestic > RESOURCES_FOR_DISORDER)
     {
         $self->subtract_production('domestic', RESOURCES_FOR_DISORDER);
-        $self->add_internal_disorder(-1 * DISORDER_REDUCTION);
+        $self->add_internal_disorder(-1 * DISORDER_REDUCTION, $world);
         $self->register_event("DISORDER LOWERED TO " . $self->internal_disorder);
     }
 }
@@ -259,6 +270,7 @@ sub add_internal_disorder
 {
     my $self = shift;
     my $disorder = shift;
+    my $world = shift;
     my $actual_disorder = $self->internal_disorder_status;
     my $new_disorder_data = $self->internal_disorder + $disorder;
     $new_disorder_data = int($new_disorder_data * 100) / 100;
@@ -277,8 +289,7 @@ sub add_internal_disorder
         $self->register_event("INTERNAL DISORDER LEVEL FROM $actual_disorder TO $new_disorder");
         if($new_disorder eq "Civil war")
         {
-            $self->register_event("CIVIL WAR OUTBREAK");
-            $self->rebel_provinces(STARTING_REBEL_PROVINCES->[$self->size]);
+            $world->start_civil_war($self);
         }
     }
 }
@@ -406,6 +417,15 @@ sub win_civil_war
             $world->broadcast_event($self->name . " AND " . $rebel_supporter->name . " ARE NOW ALLIES. " . $rebel_supporter->name . " HELPED " . $self->name . " REVOLUTION", $self->name, $rebel_supporter->name);
         }
     }
+    elsif($winner eq 'government')
+    {
+        my $rebsup = $world->rebel_supported($self->name);
+        if($rebsup)
+        {
+            my $rebel_supporter = $world->get_nation($rebsup->node1);
+            $world->stop_rebel_military_support($rebel_supporter, $self) if $rebel_supporter;
+        }
+    }  
 }
 
 sub new_government
