@@ -1,5 +1,5 @@
 package BalanceOfPower::Nation::Role::IA;
-$BalanceOfPower::Nation::Role::IA::VERSION = '0.131000';
+$BalanceOfPower::Nation::Role::IA::VERSION = '0.140000';
 use strict;
 use v5.10;
 use Moo::Role;
@@ -67,7 +67,8 @@ sub domestic_advisor
     return $self->advisor("LOWER DISORDER", 
                           "BOOST PRODUCTION",
                           "TREATY NAG WITH",
-                          "DIPLOMATIC PRESSURE ON");
+                          "DIPLOMATIC PRESSURE ON",
+                          "MILITARY AID FOR");
 }
 
 sub economy_advisor
@@ -94,7 +95,19 @@ sub accept_military_support
     my $self = shift;
     my $other = shift;
     my $world = shift;
-    return 0 if($world->already_in_military_support($self->name));
+    if($world->already_in_military_support($self->name))
+    {
+       my $supd = $world->supported($self->name);
+       if($supd && $supd->node1 eq $other)
+       {
+            return 1; 
+       }
+       else
+       {
+            return 0;
+       }
+    }
+    return 0 if($world->diplomacy_status($self->name, $other) eq 'HATE');
     return $self->army < ARMY_TO_ACCEPT_MILITARY_SUPPORT;
 }
 
