@@ -1,12 +1,14 @@
 package BalanceOfPower::Relations::War;
-$BalanceOfPower::Relations::War::VERSION = '0.131000';
+$BalanceOfPower::Relations::War::VERSION = '0.140000';
 use strict;
 use v5.10;
 
 use Moo;
+use BalanceOfPower::Utils qw( from_to_turns );
 use Term::ANSIColor;
 
 with 'BalanceOfPower::Relations::Role::Relation';
+with 'BalanceOfPower::Role::Reporter';
 
 has attack_leader => (
     is => 'rw',
@@ -16,18 +18,14 @@ has war_id => (
     is => 'rw',
     default => ""
 );
+has name => (
+    is => 'rw',
+    default => "WAR"
+);
 has node1_faction => (
     is => 'rw',
     default => ""
 );
-has node1_starting_army => (
-    is => 'rw',
-    default => 0
-);
-has node2_starting_army => (
-    is => 'rw',
-    default => 0
-);
 has node2_faction => (
     is => 'rw',
     default => ""
@@ -38,7 +36,7 @@ has start_date => (
 has end_date => (
     is => 'rw'
 );
-has ending_line => (
+has current_year => (
     is => 'rw'
 );
 
@@ -72,11 +70,17 @@ sub print_history
     my $out = "";
     $out .= "### WAR " .  $self->war_id . "\n";
     $out .= $self->node1 . " => " . $self->node2 . "\n";
-    $out .= "War started in " . $self->start_date . "\n";
-    $out .= "Starting army for " . $self->node1 . ": " . $self->node1_starting_army . "\n";
-    $out .= "Starting army for " . $self->node2 . ": " . $self->node2_starting_army . "\n";
-    $out .= "War ended in " . $self->end_date . "\n";
-    $out .= $self->ending_line . "\n";
+    $out .= "*** War started in " . $self->start_date . " ***\n";
+    $out .= $self->print_turn_events_notitle("START");
+    for(from_to_turns($self->start_date, $self->end_date))
+    {
+        my $events = $self->print_turn_events_inline_year($_);
+        if($events)
+        {
+            $out .= $events;
+        }
+    }
+    $out .= "*** War ended in " . $self->end_date . " ***\n";
     return $out;
 }
 
