@@ -1,9 +1,10 @@
 package BalanceOfPower::Role::Historian;
-$BalanceOfPower::Role::Historian::VERSION = '0.131000';
+$BalanceOfPower::Role::Historian::VERSION = '0.140000';
 use v5.10;
 use strict;
 use Moo::Role;
 use Term::ANSIColor;
+use List::Util qw( min max );
 
 use BalanceOfPower::Utils qw( get_year_turns as_title from_to_turns );
 use BalanceOfPower::Constants ':all';
@@ -16,6 +17,7 @@ has statistics => (
 );
 
 requires 'get_nation';
+requires 'get_wars';
 
 
 
@@ -72,6 +74,88 @@ sub print_nation_statistics
     }
     return $out;
 }
+sub print_nation_factor
+{
+    my $self = shift;
+    my $nation = shift;
+    my $factor = shift;
+    my $first_turn = shift;
+    my $last_turn = shift;
+    my $out = as_title($nation . " - " . $factor . " - column of values" . "\n===\n");
+    foreach my $t (from_to_turns($first_turn, $last_turn))
+    {
+        if(defined $self->get_statistics_value($t, $nation, $factor))
+        {
+            $out .=  $self->get_statistics_value($t, $nation, $factor) . "\n";
+        }
+        else
+        {
+            $out .= "*** UNAVAILABLE ***" . "\n";
+        }
+    }
+    return $out;
+}
+
+sub plot_nation_factor
+{
+    my $self = shift;
+    my $nation = shift;
+    my $factor = shift;
+    my $first_turn = shift;
+    my $last_turn = shift;
+    
+    my $graph_height = 12;
+
+    my @data = ();
+    foreach my $t (from_to_turns($first_turn, $last_turn))
+    {
+        if(defined $self->get_statistics_value($t, $nation, $factor))
+        {
+            push @data, $self->get_statistics_value($t, $nation, $factor);
+        }
+        else
+        {
+            push @data, undef;
+        }
+    }
+    return "" if(@data == 0);
+    my $min = min @data;
+    my $max = max @data;
+    my $step = ($max - $min) / $graph_height;
+    my @lines = ();
+    my $out = as_title($nation . " - " . $factor . " - graph " . "\n===\n");
+    $out .= "Min. value: $min   Max. value: $max\n\n";
+    for(my $i = 0; $i <= $graph_height; $i++)
+    {
+        $lines[$i] = "";
+        my $level =  $step * ( $graph_height - $i);
+        for(@data)
+        {
+            my $v = $_;
+            if(! $v)
+            {
+                $lines[$i] .= " ";
+            }
+            else
+            {
+                #if(($v - $min) < $step * ( $graph_height - ($i-1)) && 
+                if(($v - $min) >= $level)
+                {
+                    $lines[$i] .= "o";
+                }
+                else
+                {
+                    $lines[$i] .= " ";
+                }
+            }
+        }
+        my $level_label = int($level * 100) / 100 + $min;
+        $out .= $lines[$i] . "...$level_label" ."\n";
+    }
+    return $out . "\n";
+}
+
+
 sub print_nation_statistics_header
 {
     if(DEBT_ALLOWED)
@@ -263,9 +347,9 @@ sub print_defcon_statistics
         }
     }
     return $out;
-       
 }
 
+
 1;
 
 
