@@ -1,5 +1,5 @@
 package BalanceOfPower::Role::Ruler;
-$BalanceOfPower::Role::Ruler::VERSION = '0.131000';
+$BalanceOfPower::Role::Ruler::VERSION = '0.140000';
 use strict;
 use Moo::Role;
 
@@ -81,6 +81,24 @@ sub has_influence
     }
     return @out;
 }
+sub empire
+{
+    my $self = shift;
+    my $n = shift;
+    if(my $domination = $self->is_under_influence($n))
+    {
+        my $dominator = $domination;
+        my @allies = $self->has_influence($dominator);
+        push @allies, $dominator;
+        return @allies;
+    }
+    else
+    {
+        my @allies = $self->has_influence($n);
+        push @allies, $n;
+        return @allies;
+    }
+}
 sub occupy
 {
     my $self = shift;
@@ -98,6 +116,8 @@ sub occupy
                                                                        status => 0,
                                                                        next => $internal_disorder ? 2 : 1,
                                                                        clock => 0 ));
+            $self->set_diplomacy($nation, $c, DOMINION_DIPLOMACY);
+            $self->copy_diplomacy($c, $nation);
         }
         else
         {
@@ -105,6 +125,7 @@ sub occupy
                                                                        node2 => $nation,
                                                                        status => 0,
                                                                        clock => 0 ));
+            $self->set_diplomacy($nation, $c, DIPLOMACY_AFTER_OCCUPATION);
         }
         $self->broadcast_event("$c OCCUPIES $nation", $c, $nation);
     }
