@@ -1,12 +1,11 @@
 package BalanceOfPower::Role::Warlord;
-$BalanceOfPower::Role::Warlord::VERSION = '0.131000';
+$BalanceOfPower::Role::Warlord::VERSION = '0.140000';
 use strict;
 use v5.10;
 
 use Moo::Role;
 
 use Term::ANSIColor;
-use Data::Dumper;
 
 use BalanceOfPower::Constants ':all';
 use BalanceOfPower::Utils qw( as_title );
@@ -91,7 +90,14 @@ sub in_military_range
     return 0;
 }
 
-
+sub war_current_year
+{
+    my $self = shift;
+    for($self->wars->all)
+    {
+        $_->current_year($self->current_year);
+    }
+}
 
 sub create_war
 {
@@ -248,16 +254,17 @@ sub create_war
         }
         my %attacker_leaders;
         my $war_id = time;
-        $self->add_war( BalanceOfPower::Relations::War->new(node1 => $attacker->name, 
-                                                            node2 => $defender->name,
-                                                            attack_leader => $attacker->name,
-                                                            war_id => $war_id,
-                                                            node1_faction => 0,
-                                                            node2_faction => 1,
-                                                            node1_starting_army => $attacker->army,
-                                                            node2_starting_army => $defender->army,
-                                                            start_date => $self->current_year
-                                                            ) );
+        my $war = BalanceOfPower::Relations::War->new(node1 => $attacker->name, 
+                                                      node2 => $defender->name,
+                                                      attack_leader => $attacker->name,
+                                                      war_id => $war_id,
+                                                      node1_faction => 0,
+                                                      node2_faction => 1,
+                                                      start_date => $self->current_year,
+                                                      log_active => 0,
+                                                      );
+        $war = $self->war_starting_report($war);
+        $self->add_war($war); 
         $attacker_leaders{$defender->name} = $attacker->name;                                              
         $self->broadcast_event("WAR BETWEEN " . $attacker->name . " AND " .$defender->name . " STARTED", $attacker->name, $defender->name);
         my $faction_counter = 0;
@@ -285,16 +292,42 @@ sub create_war
                 $faction1 = 1;
                 $faction2 = 0;
             }
-            $self->add_war(BalanceOfPower::Relations::War->new(node1 => $c->[0], 
-                                                          node2 => $c->[1],
+            my $node1 = $c->[0];
+            my $node2 = $c->[1];
+            my $war = BalanceOfPower::Relations::War->new(node1 => $node1, 
+                                                          node2 => $node2,
                                                           attack_leader => $leader,
                                                           war_id => $war_id,
                                                           node1_faction => $faction1,
-                                                          node2_faction => $faction2));
-            $self->broadcast_event("WAR BETWEEN " . $c->[0] . " AND " . $c->[1] . " STARTED (LINKED TO WAR BETWEEN " . $attacker->name . " AND " .$defender->name . ")", $c->[0], $c->[1]);
+                                                          node2_faction => $faction2,
+                                                          start_date => $self->current_year,
+                                                          log_active => 0);
+            $war = $self->war_starting_report($war);
+            $self->add_war($war);                                                  
+            $self->broadcast_event("WAR BETWEEN " . $node1 . " AND " . $node2 . " STARTED (LINKED TO WAR BETWEEN " . $attacker->name . " AND " .$defender->name . ")", $node1, $node2);
         }
     }
 }
+sub war_starting_report
+{
+    my $self = shift;
+    my $war = shift;
+    my $node1 = $war->node1;
+    my $node2 = $war->node2;
+    $war->register_event("Starting army for " . $node1 . ": " . $self->get_nation($node1)->army);
+    my $sup1 = $self->supported($node1);
+    if($sup1)
+    {
+        $war->register_event("$node1 is supported by " . $sup1->node1 . ": " . $sup1->army);
+    }
+    $war->register_event("Starting army for " . $node2 . ": " . $self->get_nation($node2)->army);
+    my $sup2 = $self->supported($node2);
+    if($sup2)
+    {
+        $war->register_event("$node2 is supported by " . $sup2->node1 . ": " . $sup2->army);
+    }
+    return $war;
+}
 
 sub army_for_war
 {
@@ -346,6 +379,7 @@ sub damage_from_battle
         if($supported->army <= 0)
         {
             $self->broadcast_event("MILITARY SUPPORT TO " . $supported->node2 . " BY " . $supported->node1 . " DESTROYED", $supported->node1, $supported->node2);
+            $self->war_report("Military support to ". $supported->node2 . " by " . $supported->node1 . " destroyed", $supported->node2);
         }
     }
     $self->military_support_garbage_collector();
@@ -423,7 +457,8 @@ sub lose_war
 {
     my $self = shift;
     my $loser = shift;
-    my $internal_disorder ||= 0;
+    my $internal_disorder = shift;
+    $internal_disorder ||= 0;
     my @wars = $self->get_wars($loser);
     my $retreat_penality = 0;
     my @conquerors = ();
@@ -448,14 +483,11 @@ sub lose_war
             $self->delete_crisis($loser, $other);
             $conquerors_leader = $w->attack_leader;
             $winner_role = "[ATTACKER]";
+            $self->get_nation($loser)->internal_disorder(AFTER_CONQUERED_INTERNAL_DISORDER);
         }
         my $ending_line = "WAR BETWEEN $other AND $loser WON BY $other $winner_role";
         $self->broadcast_event($ending_line, $other, $loser);
         my $history_line = "";
-        if($internal_disorder)
-        {
-            $history_line = "Civil war outbreaked in $loser.\n"; 
-        }
         $history_line .= "$other $winner_role won the war";
         $self->delete_war($other, $loser, $history_line);
     }
@@ -473,7 +505,7 @@ sub delete_war
     my $ending_line = shift;
     my $war = $self->war_exists($nation1, $nation2);
     $war->end_date($self->current_year);
-    $war->ending_line($ending_line);
+    $war->register_event($ending_line);
     push @{$self->memorial}, $war;
     $self->delete_war_link($nation1, $nation2);
 }
@@ -514,4 +546,6 @@ sub print_wars
     }
     return $out;
 }
+
+
 1;
