@@ -1,5 +1,5 @@
 package BalanceOfPower::World;
-$BalanceOfPower::World::VERSION = '0.131000';
+$BalanceOfPower::World::VERSION = '0.140000';
 use strict;
 use v5.10;
 
@@ -39,6 +39,10 @@ has order => (
     is => 'rw',
     default => ""
 );
+has ia_orders => (
+    is => 'rw',
+    default => sub { [] }
+);
 has autoplay => (
     is => 'rw',
     default => 0
@@ -72,8 +76,8 @@ with 'BalanceOfPower::Role::Player';
 with 'BalanceOfPower::Role::Herald';
 with 'BalanceOfPower::Role::Ruler';
 with 'BalanceOfPower::Role::Mapmaker';
-with 'BalanceOfPower::Role::Diplomat';
 with 'BalanceOfPower::Role::Supporter';
+with 'BalanceOfPower::Role::Diplomat';
 with 'BalanceOfPower::Role::Merchant';
 with 'BalanceOfPower::Role::Warlord';
 with 'BalanceOfPower::Role::CrisisManager';
@@ -245,6 +249,7 @@ sub pre_decisions_elaborations
     my $self = shift;
     my $t = shift;
     $self->init_year($t);
+    $self->war_current_year();
     $self->war_debts();
     $self->crisis_generator();
 }
@@ -266,6 +271,7 @@ sub elaborate_turn
     my $self = shift;
     my $t = shift;
     $self->pre_decisions_elaborations($t);
+    $self->decisions();
     $self->post_decisions_elaborations();
 }
 
@@ -460,7 +466,7 @@ sub calculate_prestige
 sub execute_decisions
 {   
     my $self = shift;
-    my @decisions = $self->decisions();
+    my @decisions = @{$self->ia_orders};
     my @route_adders = ();
     foreach my $d (@decisions)
     {
@@ -475,7 +481,7 @@ sub execute_decisions
         elsif($d =~ /^(.*): LOWER DISORDER$/)
         {
            my $nation = $self->get_nation($1);
-           $nation->lower_disorder();
+           $nation->lower_disorder($self);
         }
         elsif($d =~ /^(.*): BUILD TROOPS$/)
         {
@@ -500,7 +506,7 @@ sub execute_decisions
         {
             my $supporter = $self->get_nation($1);
             my $supported = $self->get_nation($2);
-            if($supported->accept_military_support($supporter, $self))
+            if($supported->accept_military_support($supporter->name, $self))
             {
                 $self->start_military_support($supporter, $supported);
             }
@@ -537,7 +543,8 @@ sub execute_decisions
         {
             my $nation1 = $self->get_nation($1);
             my $nation2 = $self->get_nation($2);
-            if($self->rebel_supported($nation2->name))
+            my $rebsup = $self->rebel_supported($nation2->name);
+            if($rebsup && $rebsup->node1 ne $nation1->name)
             {
                 $self->broadcast_event("REBEL SUPPORT IN " . $nation2->name . " IMPOSSIBLE FOR " . $nation1->name, $nation1->name, $nation2->name);
             }
@@ -548,12 +555,35 @@ sub execute_decisions
         }
         elsif($d =~ /^(.*): DIPLOMATIC PRESSURE ON (.*)$/)
         {
-            my $nation1 = $self->get_nation($1);
+            my $n1 = $1;
+            my $n2 = $2;
+            my $nation1 = $self->get_nation($n1);
             if($nation1->prestige >= DIPLOMATIC_PRESSURE_PRESTIGE_COST)
             {
-                $self->diplomatic_pressure($1, $2);
+                my $under_infl = $self->is_under_influence($n2); 
+                $under_infl ||= "";
+                if($under_infl ne $n1)
+                {
+                    $self->diplomatic_pressure($n1, $n2);
+                }
+                else
+                {
+                    $self->broadcast_event("DIPLOMATIC PRESSURE ON $n2 BY $n1 IMPOSSIBLE! $n2 IS UNDER INFLUENCE OF $n1", $n1, $n2);
+                }
             }
         }
+        elsif($d =~ /^(.*): RECALL REBEL MILITARY SUPPORT (.*)$/)
+        {
+           my $supporter = $self->get_nation($1);
+           my $supported = $self->get_nation($2);
+           $self->stop_rebel_military_support($supporter, $supported);
+        }
+        elsif($d =~ /^(.*): MILITARY AID FOR (.*)$/)
+        {
+            my $nation1 = $self->get_nation($1);
+            my $nation2 = $self->get_nation($2);
+            $self->military_aid($nation1, $nation2);
+        }
     }
     $self->manage_route_adding(@route_adders);
 }
@@ -627,7 +657,7 @@ sub decisions
             push @decisions, $decision;
         }
     }
-    return @decisions;
+    $self->ia_orders(\@decisions);
 }
 
 # DECISIONS END ###########################################################
@@ -691,13 +721,6 @@ sub internal_conflict
 
         $n->calculate_disorder($self);
         
-        #This should happen only if status changed during this iteration
-        if($n->internal_disorder_status eq 'Civil war' && $present_status ne 'Civil war')
-        {
-            $self->lose_war($n->name, 1);
-        }
-        
-        #my $winner = $n->fight_civil_war($self->random(0, 100, "Civil war " . $n->name . ": government fight result"), $self->random(0, 100, "Civil war " . $n->name . ": rebels fight result"));
         my $winner = $n->fight_civil_war($self);
         if($winner && $winner eq 'rebels')
         {
@@ -718,11 +741,11 @@ sub aid_insurgents
     my $self = shift;
     my $nation1 = shift;
     my $nation2 = shift;
-    if($nation1->production_for_export > AID_INSURGENTS_COST && $nation2->internal_disorder_status ne 'Civil war')
+    if($nation1->production_for_export >= AID_INSURGENTS_COST && $nation2->internal_disorder_status ne 'Civil war')
     {
         $self->broadcast_event("AIDS FOR INSURGENTS OF " . $nation2->name . " FROM " . $nation1->name, $nation1->name, $nation2->name);
         $nation1->subtract_production('export', AID_INSURGENTS_COST);
-        $nation2->add_internal_disorder(INSURGENTS_AID);
+        $nation2->add_internal_disorder(INSURGENTS_AID, $self);
     }
 }
 
@@ -734,6 +757,15 @@ sub at_civil_war
     return $nation->internal_disorder_status eq 'Civil war';
 }
 
+sub start_civil_war
+{
+    my $self = shift;
+    my $nation = shift;
+    $self->broadcast_event("CIVIL WAR OUTBREAK IN " . $nation->name, $nation->name);
+    $nation->rebel_provinces(STARTING_REBEL_PROVINCES->[$nation->size]);
+    $self->war_report("Civil war in " . $nation->name . "!", $nation->name);
+    $self->lose_war($nation->name, 1);
+}
 
 # INTERNAL DISORDER END ######################################################
 
@@ -748,6 +780,31 @@ sub warfare
         $self->set_statistics_value($n, 'army', $n->army);    
     }    
 }
+
+sub military_aid
+{
+    my $self = shift;
+    my $nation1 = shift;
+    my $nation2 = shift;
+    $nation1->subtract_production('export', MILITARY_AID_COST);
+    $nation2->add_army(ARMY_UNIT);
+    $self->broadcast_event("MILITARY AID FROM " . $nation1->name . " TO " . $nation2->name, $nation1->name, $nation2->name);
+    $self->change_diplomacy($nation1->name, $nation2->name, MILITARY_AID_DIPLOMACY_FACTOR);
+}
+
+sub war_report
+{
+    my $self = shift;
+    my $message = shift;
+    my $nation = shift;
+    my @wars = $self->get_wars($nation);
+    for(@wars)
+    {
+         $_->register_event($message);
+    }
+}
+
+
 # WAR END ##################################################################
 
 # TREATIES #################################################################
@@ -821,7 +878,6 @@ sub collect_events
     my $self = shift;
     my @events_to_collect = ("DISORDER LOWERED TO",
                              "INTERNAL DISORDER LEVEL FROM",
-                             "CIVIL WAR OUTBREAK",
                              "THE GOVERNMENT WON THE CIVIL WAR",
                              "THE REBELS WON THE CIVIL WAR",
                              "NEW GOVERNMENT CREATED",
